@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest_lib import exceptions
+from tempest.lib import exceptions
 
 from manilaclient.tests.functional import base
 
