@@ -14,7 +14,7 @@
 #    under the License.
 
 import ddt
-from tempest_lib.common.utils import data_utils
+from tempest.lib.common.utils import data_utils
 
 from manilaclient.tests.functional import base
 
